@@ -1,6 +1,6 @@
 # Release information about Select-Shuttle
 
-version = "1.1.1"
+version = "1.2"
 
 description = """\
 The SelectShuttle widget provides a mechanism for selecting \
@@ -9,10 +9,7 @@ between two lists. On modern browsers you can also double click an item to \
 move it from one list to the other. After the first "move", all entries \
 will be sorted automatically accordingly to its "description" on both \
 lists. Take a look at the code for SelectShuttleDesc for an example of how \
-to use this widget in your code. \
-\
-This release was greatly based on Alberto Valverde's enhancements and conversion \
-to CompoundWidgets."""
+to use this widget in your code."""
 
 author = "Jorge Godoy"
 
@@ -20,4 +17,4 @@ email = "jgodoy@gmail.com"
 
 url = "http://www.g2ctech.com/"
 download_url = "http://www.g2ctech.com/widgets/Select_Shuttle-%s-py2.5.egg" % version
-license = "MIT"
+license = "MIT"
\ No newline at end of file
